@@ -8,7 +8,7 @@ use Rose::DB::Object::MakeMethods::Generic;
 use Rose::DB::Object::Metadata::Column;
 our @ISA = qw(Rose::DB::Object::Metadata::Column);
 
-our $VERSION = '0.04';
+our $VERSION = '0.64';
 
 __PACKAGE__->add_common_method_maker_argument_names
 (
@@ -28,6 +28,8 @@ foreach my $type (__PACKAGE__->available_method_types)
   __PACKAGE__->method_maker_type($type => 'bitfield')
 }
 
+# sub dbi_data_type { DBI::SQL_INTEGER() }
+
 sub parse_value
 {
   my $self  = shift;
@@ -59,6 +61,12 @@ sub init_with_dbi_column_info
   return;
 }
 
+sub should_inline_value
+{
+  #my($self, $db, $value) = @_;
+  return (defined $_[2] && ($_[1]->should_inline_bitfield_values || $_[2] =~ /^\w+\(.*\)$/)) ? 1 : 0;
+}
+
 sub method_uses_formatted_key
 {
   my($self, $type) = @_;
@@ -66,6 +74,29 @@ sub method_uses_formatted_key
   return 0;
 }
 
+sub select_sql
+{
+  my($self) = shift;
+
+  # Optional args: db, table alias
+
+  if(my $db = shift)
+  {
+    if(@_) # table alias arg too
+    {
+      return $db->select_bitfield_column_sql($self->{'name'}, @_);
+    }
+    else
+    {
+      return $self->{'select_sql'}{$db->{'driver'}} ||= $db->select_bitfield_column_sql($self->{'name'});
+    }
+  }
+  else
+  {
+    return $self->{'name'};
+  }
+}
+
 1;
 
 __END__
